summaryrefslogtreecommitdiffstats
path: root/kmail/editorwatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/editorwatcher.h')
-rw-r--r--kmail/editorwatcher.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/editorwatcher.h b/kmail/editorwatcher.h
index 68fdb54e..daa35d8a 100644
--- a/kmail/editorwatcher.h
+++ b/kmail/editorwatcher.h
@@ -44,11 +44,11 @@ class EditorWatcher : public TQObject
* Constructs an EditorWatcher.
* @param tqparent the tqparent object of this EditorWatcher, which will take care of deleting
* this EditorWatcher if the tqparent is deleted.
* @param tqparentWidget the tqparent widget of this EditorWatcher, which will be used as the tqparent
* widget for message dialogs.
*/
EditorWatcher( const KURL &url, const TQString &mimeType, bool openWith,
- TQObject *tqparent, TQWidget *tqparentWidget );
+ TQObject *tqparent, TQWidget *parentWidget );
bool start();
bool fileChanged() const { return mFileModified; }
signals:
@@ -44,11 +44,11 @@ class EditorWatcher : public TQObject
* @param tqparent the tqparent object of this EditorWatcher, which will take care of deleting
* this EditorWatcher if the tqparent is deleted.
- * @param tqparentWidget the tqparent widget of this EditorWatcher, which will be used as the tqparent
+ * @param parentWidget the tqparent widget of this EditorWatcher, which will be used as the tqparent
* widget for message dialogs.
*/